@@ -52,8 +52,7 @@ class FittingDashboard(BaseDashboard):
     def display(self):
         load_hbox = widgets.HBox(children=[self.load_eci_button, self.load_eci_text])
         save_hbox = widgets.HBox(children=[self.save_eci_button, self.save_eci_text])
-        display(load_hbox, save_hbox)
-        display(self.tab)
+        display(save_hbox, load_hbox, self.tab)
 
     @update_statusbar
     @utils.disable_cls_widget("load_eci_button")
